You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2019/08/06 09:50:01 UTC

[camel] 13/20: CAMEL-13792 - Rename components to default names, Camel-quartz2 to camel-quartz - Fixed references camel-blueprint

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit c2794a6987925fb8237594ed1c06c193618ccbda
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Tue Aug 6 10:57:11 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-quartz2 to camel-quartz - Fixed references camel-blueprint
---
 .../org/apache/camel/blueprint/handler/CamelNamespaceHandler.java   | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/components/camel-blueprint/src/main/java/org/apache/camel/blueprint/handler/CamelNamespaceHandler.java b/components/camel-blueprint/src/main/java/org/apache/camel/blueprint/handler/CamelNamespaceHandler.java
index b0e6469..4a6e4c6 100644
--- a/components/camel-blueprint/src/main/java/org/apache/camel/blueprint/handler/CamelNamespaceHandler.java
+++ b/components/camel-blueprint/src/main/java/org/apache/camel/blueprint/handler/CamelNamespaceHandler.java
@@ -1220,11 +1220,11 @@ public class CamelNamespaceHandler implements NamespaceHandler {
                         value = parameters.get("consumer.scheduler");
                     }
                     if (value != null) {
                         // the scheduler can be quartz2 or spring based, so add reference to camel component
                         // from these components os blueprint knows about the requirement
                         String name = value.toString();
-                        if ("quartz2".equals(name)) {
-                            components.add("quartz2");
+                        if ("quartz".equals(name)) {
+                            components.add("quartz");
                         } else if ("spring".equals(name)) {
                             components.add("spring-event");
                         }
@@ -1220,11 +1220,11 @@ public class CamelNamespaceHandler implements NamespaceHandler {
                     }
                     if (value != null) {
-                        // the scheduler can be quartz2 or spring based, so add reference to camel component
+                        // the scheduler can be quartz or spring based, so add reference to camel component
                         // from these components os blueprint knows about the requirement
                         String name = value.toString();